"""
Export locators for GridSat imagery products.

Classes:
    - GridSatProductLocatorB1: Locator for B1 products.
    - GridSatProductLocatorGC: Locator for GC products.
"""

from .locator_b1 import GridSatProductLocatorB1 as GridSatProductLocatorB1
from .locator_gc import GridSatProductLocatorGC as GridSatProductLocatorGC

__all__ = ["GridSatProductLocatorB1", "GridSatProductLocatorGC"]



"""
Export class providing the base functionalities for product locators.

Classes:
    - ProductLocatorGG: Abstract a GridSat or GOES-R series dataset
      product locator.
"""

from .locator_gg import ProductLocatorGG as ProductLocatorGG

__all__ = ["ProductLocatorGG"]



"""Provide functionality for downloading GOES and GridSat datasets."""

__package_id__ = "GOES-DL"
__package_name__ = (
    f"{__package_id__} — GOES Satellite Imagery Dataset Downloader"
)
__version__ = "v0.1-rc5"



"""
Export class providing the base functionalities for product locators.

Classes:
    - ProductLocator: Abstract a product locator for GridSat family of
    imagery datasets.
"""

from .locator import ProductLocator as ProductLocator

__all__ = ["ProductLocator"]
